Aggregation examples
====================

Examples of how to use the earthkit-transforms.aggregate modules


.. toctree::
   :maxdepth: 1

   temporal/index.rst
   climatology/index.rst
   spatial/index.rst
